#ifndef NT2_INCLUDE_FUNCTIONS_BETA_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_BETA_HPP_INCLUDED

#include <nt2/euler/include/functions/beta.hpp>

#endif
